package com.qmth.distributed.print.api;

import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.bean.result.EditResult;
import com.qmth.teachcloud.common.annotation.OperationLogDetail;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.enums.log.CustomizedOperationTypeEnum;
import com.qmth.teachcloud.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.io.IOException;

/**
 * <p>
 * 期末考试成绩表 前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2024-02-18
 */
@Api(tags = "课程目标达成度-成绩管理-期末考试成绩Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_COURSE_DEGREE)
public class TCScoreEndExamController {

    @ApiOperation(value = "导入期末成绩-模板下载")
    @RequestMapping(value = "/score/end_exam/template_download", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.EXPORT)
    @ApiResponses({@ApiResponse(code = 200, message = "下载成功", response = Object.class)})
    public void endExamTemplateDownload(@ApiParam(value = "考试id", required = true) @RequestParam Long examId,
                                        @ApiParam(value = "科目编码", required = true) @RequestParam String courseCode,
                                        @ApiParam(value = "试卷编号", required = true) @RequestParam String paperNumber,
                                        @ApiParam(value = "试卷类型", required = true) @RequestParam String paperType) throws IOException {
//        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
//        examDetailService.downLoadExaminationTemplate(schoolId, ServletUtil.getResponse());
    }

    @ApiOperation(value = "导入期末成绩")
    @RequestMapping(value = "/score/end_exam/import", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.IMPORT)
    @ApiResponses({@ApiResponse(code = 200, message = "导入成功", response = EditResult.class)})
    public Object scoreEndExamImport(@ApiParam(value = "上传文件", required = true) @RequestParam MultipartFile file) throws IOException {
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "期末成绩列表")
    @RequestMapping(value = "/score/end_exam/list", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.SEARCH)
    @ApiResponses({@ApiResponse(code = 200, message = "导入成功", response = EditResult.class)})
    public Object scoreEndExamList(@ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                                   @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) throws IOException {
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "期末成绩编辑")
    @RequestMapping(value = "/score/end_exam/edit", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.EDIT)
    @ApiResponses({@ApiResponse(code = 200, message = "编辑", response = EditResult.class)})
    public Object scoreEndExamEdit(@ApiParam(value = "主键", required = true) @RequestParam Long id) throws IOException {
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "期末成绩保存")
    @RequestMapping(value = "/score/end_exam/save", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.UPDATE)
    @ApiResponses({@ApiResponse(code = 200, message = "保存", response = EditResult.class)})
    public Object scoreEndExamSave(@ApiParam(value = "主键", required = true) @RequestParam Long id,
                                   @ApiParam(value = "期末成绩", required = true) @RequestParam Double score,
                                   @ApiParam(value = "期末成绩明细", required = true) @RequestParam String scoreDetail) throws IOException {
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "期末成绩启用/禁用")
    @RequestMapping(value = "/score/end_exam/enable", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.UPDATE)
    @ApiResponses({@ApiResponse(code = 200, message = "编辑", response = EditResult.class)})
    public Object scoreEndExamEnable(@ApiParam(value = "主键", required = true) @RequestParam Long id,
                                     @ApiParam(value = "启用/禁用", required = true) @RequestParam Boolean enable) throws IOException {
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "期末成绩试卷蓝图保存")
    @RequestMapping(value = "/score/end_exam/paper_positive/save", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.UPDATE)
    @ApiResponses({@ApiResponse(code = 200, message = "试卷蓝图保存", response = Object.class)})
    public Object scoreEndExamPaperPositiveSave(@ApiParam(value = "试卷蓝图结构", required = true) @RequestBody Object body) throws IOException {
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "期末成绩试卷蓝图查询")
    @RequestMapping(value = "/score/end_exam/paper_positive/query", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.SEARCH)
    @ApiResponses({@ApiResponse(code = 200, message = "试卷蓝图保存", response = Object.class)})
    public Object scoreEndExamPaperPositiveQuery(@ApiParam(value = "考试id", required = true) @RequestParam Long examId,
                                                 @ApiParam(value = "科目编码", required = true) @RequestParam String courseCode,
                                                 @ApiParam(value = "试卷编号", required = true) @RequestParam String paperNumber,
                                                 @ApiParam(value = "试卷类型", required = true) @RequestParam String paperType) throws IOException {
        return ResultUtil.ok(true);
    }
}
